calibrate.class objectsSee the function calibrate which produces an instance of this class
This class comes with a set of methods, some of them being useful for the user:
See the documentation for calibrate... Other methods
should not be called as they are designed to be used during the calibration process.
Fields should not be changed or manipulated by the user as they are updated internally during the estimation process.
calibrate.classAn object of class R6ClassGenerator of length 24.
mda model.class object generated by model
pra prior.class object generated by prior
opt.estimlist of estimation options (see calibrate for details)
opt.validlist of cross validation options (see calibrate for details)
logPostthe log posterior
mcmca coda variable of the generated chains
outputlist of several chains and acceptation ratios
onlyCVactivates only the cross validation
errorCVoutput of the CV errors
n.coresnumber cores available
binfthe lower bound of the parameters for the DOE
bsupthe upper bound of the parameters for the DOE